==> plasma-nm_0.9.3.3.orig.tar.xz: plasma-nm-0.9.3.3/applet/declarative/metadata.desktop.cmake <==
[Desktop Entry]
Name=Network Management
Name[bs]=Upravljanje mrežom
Name[ca]=Gestió de la xarxa
Name[cs]=Správa sítě
Name[da]=Netværkshåndtering
Name[de]=Netzwerkverwaltung
Name[el]=Διαχείριση δικτύων
Name[es]=Gestión de red
Name[fi]=Verkonhallinta
Name[fr]=Gestion de réseau
Name[hu]=Hálózatkezelés
Name[nl]=Netwerkbeheer
Name[pl]=Zarządzanie siecią
Name[pt]=Gestão de Rede
Name[pt_BR]=Gerenciamento de rede
Name[ro]=Gestiunea rețelei
Name[sk]=Správa siete
Name[sl]=Omrežno upravljanje
Name[sv]=Nätverkshantering
Name[tr]=Ağ Yönetimi
Name[ug]=تور باشقۇرۇش
Name[uk]=Керування мережею
Name[x-test]=xxNetwork Managementxx
Name[zh_CN]=网络管理

Comment=Network status and control
Comment[bs]=Alat za kontrolu i prikaz stanja mreže
Comment[ca]=Control i estat de la xarxa
Comment[cs]=Stav a ovládání sítě
Comment[da]=Status og kontrol over netværk
Comment[de]=Netzwerkstatus und -steuerung
Comment[el]=Κατάσταση δικτύου και έλεγχος
Comment[es]=Estado y control de la red
Comment[fi]=Verkon tila ja hallinta
Comment[fr]=État et contrôle du réseau
Comment[hu]=Hálózatállapot és vezérlés
Comment[nl]=Netwerkstatus en besturing
Comment[pl]=Stan i sterowanie siecią
Comment[pt]=Estado e controlo da rede
Comment[pt_BR]=Estado e controle da rede
Comment[ro]=Starea și controlul rețelei
Comment[sk]=Správa a ovládanie siete
Comment[sl]=Stanje omrežja in nadzor
Comment[sv]=Nätverksstatus och kontroll
Comment[tr]=Ağ denetim ve durum izleme
Comment[uk]=Стеження за станом і керування мережею
Comment[x-test]=xxNetwork status and controlxx
Comment[zh_CN]=网络状态和控制

Type=Service
ServiceTypes=Plasma/Applet,Plasma/PopupApplet
Icon=network-defaultroute

X-Plasma-API=declarativeappletscript
X-Plasma-MainScript=ui/main.qml
X-Plasma-DefaultSize=350,450
X-Plasma-NotificationArea=true
X-Plasma-ConfigPlugins=networkmanagement_notifications

X-KDE-PluginInfo-Name=org.kde.networkmanagement
X-KDE-PluginInfo-Category=System Information
X-KDE-PluginInfo-Author=Jan Grulich,Lukáš Tinkl
X-KDE-PluginInfo-Email=jgrulich@redhat.com,ltinkl@redhat.com
X-KDE-PluginInfo-Version=@PLASMA_NM_VERSION@
X-KDE-PluginInfo-Website=https://projects.kde.org/plasma-nm
X-KDE-PluginInfo-License=GPL
X-KDE-PluginInfo-EnabledByDefault=true
X-KDE-ServiceTypes=Plasma/Applet,Plasma/PopupApplet

==> plasma-nm_0.9.3.4.orig.tar.xz: plasma-nm-0.9.3.4/applet/declarative/metadata.desktop.cmake <==
[Desktop Entry]
Name=Network Management
Name[bg]=Управление на мрежа
Name[bs]=Upravljanje mrežom
Name[ca]=Gestió de la xarxa
Name[ca@valencia]=Gestió de la xarxa
Name[cs]=Správa sítě
Name[da]=Netværkshåndtering
Name[de]=Netzwerkverwaltung
Name[el]=Διαχείριση δικτύων
Name[en_GB]=Network Management
Name[es]=Gestión de red
Name[et]=Võrguhaldus
Name[fi]=Verkonhallinta
Name[fr]=Gestion du réseau
Name[hu]=Hálózatkezelés
Name[it]=Gestione di rete
Name[lt]=Tinklo valdymas
Name[nds]=Nettwarkpleeg
Name[nl]=Netwerkbeheer
Name[pl]=Zarządzanie siecią
Name[pt]=Gestão de Rede
Name[pt_BR]=Gerenciamento de rede
Name[ro]=Gestiunea rețelei
Name[sk]=Správa siete
Name[sl]=Omrežno upravljanje
Name[sv]=Nätverkshantering
Name[tr]=Ağ Yönetimi
Name[ug]=تور باشقۇرۇش
Name[uk]=Керування мережею
Name[x-test]=xxNetwork Managementxx
Name[zh_CN]=网络管理

Comment=Network status and control
Comment[bg]=Състояние и контрол на мрежата
Comment[bs]=Alat za kontrolu i prikaz stanja mreže
Comment[ca]=Control i estat de la xarxa
Comment[ca@valencia]=Control i estat de la xarxa
Comment[cs]=Stav a ovládání sítě
Comment[da]=Status og kontrol over netværk
Comment[de]=Netzwerkstatus und -steuerung
Comment[el]=Κατάσταση δικτύου και έλεγχος
Comment[en_GB]=Network status and control
Comment[es]=Estado y control de la red
Comment[et]=Võrgu olek ja juhtimine
Comment[fi]=Verkon tila ja hallinta
Comment[fr]=État et contrôle du réseau
Comment[hu]=Hálózatállapot és vezérlés
Comment[it]=Stato e controllo della rete
Comment[lt]=Tinklo būsena ir kontrolė
Comment[nds]=Nettwarkstatus un -stüern
Comment[nl]=Netwerkstatus en besturing
Comment[pl]=Stan i sterowanie siecią
Comment[pt]=Estado e controlo da rede
Comment[pt_BR]=Estado e controle da rede
Comment[ro]=Starea și controlul rețelei
Comment[sk]=Správa a ovládanie siete
Comment[sl]=Stanje omrežja in nadzor
Comment[sv]=Nätverksstatus och kontroll
Comment[tr]=Ağ denetim ve durum izleme
Comment[uk]=Стеження за станом і керування мережею
Comment[x-test]=xxNetwork status and controlxx
Comment[zh_CN]=网络状态和控制

Type=Service
ServiceTypes=Plasma/Applet,Plasma/PopupApplet
Icon=network-defaultroute

X-Plasma-API=declarativeappletscript
X-Plasma-MainScript=ui/main.qml
X-Plasma-DefaultSize=350,450
X-Plasma-NotificationArea=true
X-Plasma-ConfigPlugins=networkmanagement_notifications

X-KDE-PluginInfo-Name=org.kde.networkmanagement
X-KDE-PluginInfo-Category=System Information
X-KDE-PluginInfo-Author=Jan Grulich,Lukáš Tinkl
X-KDE-PluginInfo-Email=jgrulich@redhat.com,ltinkl@redhat.com
X-KDE-PluginInfo-Version=@PLASMA_NM_VERSION@
X-KDE-PluginInfo-Website=https://projects.kde.org/plasma-nm
X-KDE-PluginInfo-License=GPL
X-KDE-PluginInfo-EnabledByDefault=true
X-KDE-ServiceTypes=Plasma/Applet,Plasma/PopupApplet
